@@ -784,10 +784,7 @@ static gint *csv_import_update_fields_config (GArray *lines_tab,
 		csv_fields_config[i] = 0;
 	}
 
-	if (old_csv_fields_config)
-	{
-		g_free (old_csv_fields_config);
-	}
+	g_free (old_csv_fields_config);
 	csv_fields_config [i] = -1;
 
 	return csv_fields_config;
@@ -1842,7 +1839,7 @@ gboolean csv_import_change_separator (GtkEntry *entry,
 		GArray *lines_tab;
 
 		g_object_set_data (G_OBJECT(assistant), "separator", separator);
-		if (w_etat->csv_separator && strlen (w_etat->csv_separator) > 0)
+		if (w_etat->csv_separator)
 			g_free (w_etat->csv_separator);
 		w_etat->csv_separator = separator;
 		contents = g_object_get_data (G_OBJECT(assistant), "contents");
@@ -1856,13 +1853,12 @@ gboolean csv_import_change_separator (GtkEntry *entry,
 		lines_tab = csv_import_init_lines_tab (&contents, w_etat->csv_separator);
 		g_object_set_data (G_OBJECT(assistant), "lines-tab", lines_tab);
 		first_line_with_cols = 0;
-		csv_import_update_preview (assistant);
 	}
 	else
 	{
 		if (w_etat->csv_separator)
 			g_free (w_etat->csv_separator);
-		w_etat->csv_separator = (gchar*)"";
+		w_etat->csv_separator = NULL;
 		g_object_set_data (G_OBJECT(assistant), "separator", NULL);
 	}
 
@@ -1873,6 +1869,16 @@ gboolean csv_import_change_separator (GtkEntry *entry,
 	gtk_combo_box_set_active (GTK_COMBO_BOX(combobox), index);
 	utils_widget_csv_separators_combo_block_unblock (combobox, entry, FALSE);
 
+	/* update preview */
+	if (strlen(separator) > 0)
+	{
+		/* reset csv_fields_config */
+		g_free (csv_fields_config);
+		csv_fields_config = NULL;
+
+		csv_import_update_preview (assistant);
+	}
+
 	return FALSE;
 }
 
