@@ -11,7 +11,7 @@
 /* the VERSION_FICHIER is in fact the lowest version which can be used to open the */
 /* file, so each time we make an incompatibility issue, VERSION_FICHIER must be set */
 /* to VERSION_GRISBI */
-#define VERSION_FICHIER         "2.3.1"
+#define VERSION_FICHIER         "2.3.2"
 #define OLD_VERSION_FICHIER		"0.6.0"
 
 #define VERSION_FICHIER_ETAT    "0.6.0"
@@ -151,6 +151,7 @@ struct _GrisbiWinEtat
     gint		associate_categorie_for_payee;				/* TRUE to automatically retrieve the category of the payee if it exists */
     gint		get_fyear_by_value_date;					/* TRUE to get the fyear by value date, FALSE by date */
 	gint		import_files_nb_days;						/* Number of days for search transactions */
+	gint		import_ope_nb_days_max;						/* Number max of days imported. 0: no time limit */
 
     gchar *		csv_separator;                              /* CSV separator to use while parsing a CSV file. */
     gboolean	csv_skipped_lines [ CSV_MAX_TOP_LINES ];	/* Contains a pointer to skipped lines in CSV preview. */
@@ -563,5 +564,20 @@ enum _TransactionsField				/* the element number for each showable in the list *
     ELEMENT_CHQ
 };
 
+enum _PrimarySort
+{
+	PRIMARY_SORT_BY_VALUE_DATE,						/* 0, "Sort by value date" */
+	PRIMARY_SORT_BY_VALUE_DATE_THEN_OPERATION_DATA,	/* 1, "default" (Sort by value date and then by date) */
+	PRIMARY_SORT_FORCED_BY_DATE,					/* 2, "Forced sort by date" */
+};
+
+enum _SecondarytSort
+{
+	SECONDARY_SORT_BY_TRANSACTION_NUMBER,			/* 0, "Sort by transaction number" */
+	SECONDARY_SORT_BY_TYPE_OF_AMOUNT, 				/* 1, "Sort by type of amount" */
+	SECONDARY_SORT_BY_PAYEE_NAME, 					/* 2, "Sort by payee name */
+	SECONDARY_SORT_BY_DATE_THEN_TRANSACTION_NUMBER, /* 3, "Sort by date and then by transaction number" */
+	SECONDARY_SORT_BY_VALUE_DATE_THEN_DATE, 		/* 4, "default" (Sort by value date and then by date) */
+};
 
 #endif
